# Bank Marketing Data

## Source / Data Set Description:
<https://archive.ics.uci.edu/ml/datasets/Bank+Marketing>

The data is related with direct marketing campaigns (phone calls) of a Portuguese banking institution. The classification goal is to predict if the client will subscribe a term deposit (variable y). Dataset used is `bank-additional-full.csv` with all examples (41188) and 20
inputs, ordered by date (from May 2008 to November 2010).

Additional information on dataset and features is available in `bank-additional-names.txt`.

## Download instructions

1. Download the file [bank-additional.zip](https://archive.ics.uci.edu/ml/machine-learning-databases/00222/bank-additional.zip).

2. Extract files from the downloaded archive and place the files 'bank-additional-full.csv' and 'bank-additional-names.txt' into the current folder.

## Relevant Papers

* S. Moro, P. Cortez and P. Rita. A Data-Driven Approach to Predict the Success of Bank Telemarketing. Decision Support Systems, Elsevier, 62:22-31, June 2014